@@ -8,12 +8,16 @@
 #define KANDROIDEXTRAS_JAVATYPES_H
 
 #include <KAndroidExtras/JniTypes>
+#include <KAndroidExtras/JniTypeTraits>
 
 namespace KAndroidExtras {
 
 JNI_TYPE(java, io, File)
+JNI_TYPE(java, lang, String)
 JNI_TYPE(java, util, Locale)
 
+JNI_DECLARE_CONVERTER(java::lang::String, QString, (value.toString()), (QAndroidJniObject::fromString(value)))
+
 }
 
 #endif // KANDROIDEXTRAS_JAVATYPES_H
